@@ -1,4 +1,4 @@
-#!/usr/bin/env python
+#!/usr/bin/env python3
 
 import time
 # import yaml
@@ -33,9 +33,9 @@ class CLRunner(object) :
     @staticmethod
     def param(**kwargs) :
         def result(method) :
-            param = CLRunner._normalize_param( kwargs, kwargs['name'] if 'name' in kwargs else method.func_name )
+            param = CLRunner._normalize_param( kwargs, kwargs['name'] if 'name' in kwargs else method.__name__ )
             if param['doc'] is None :
-                param['doc'] = method.func_doc
+                param['doc'] = method.__doc__
             method._cl_param = param
             return method
         return result
@@ -43,8 +43,8 @@ class CLRunner(object) :
     @staticmethod
     def command(name=None,params=None,aliases=None,doc=None) :
         def result(method) :
-            command_name = method.func_name if name is None else name
-            command_doc = method.func_doc if doc is None else doc
+            command_name = method.__name__ if name is None else name
+            command_doc = method.__doc__ if doc is None else doc
             method._cl_command = {
                 'name' : command_name,
                 'params' : CLRunner._normalize_params( {} if params is None else params ),
@@ -78,16 +78,16 @@ class CLRunner(object) :
                         'name' : item._cl_command['name'],
                         'params' : item._cl_command['params'],
                         'aliases' : item._cl_command['aliases'],
-                        'doc' : item._cl_command['doc'] if item._cl_command['doc'] is not None else item.func_doc,
+                        'doc' : item._cl_command['doc'] if item._cl_command['doc'] is not None else item.__doc__,
                         'code' : item,
                         }
-                    delattr(item.im_func,'_cl_command')
+                    delattr(item,'_cl_command')
                     for alias in command['aliases'] :
                         commands[alias] = command
                 if hasattr(item,'_cl_param') :
                     param = item._cl_param
                     param['code'] = item
-                    delattr(item.im_func,'_cl_param')
+                    delattr(item,'_cl_param')
                     for alias in param['aliases'] :
                         global_params[alias] = param
 
